@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2001 Hiroyuki Yamamoto
+ * Copyright (C) 1999-2002 Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -174,9 +174,11 @@ void compose_new_with_recipient	(PrefsAccount	*account,
 void compose_reply		(MsgInfo	*msginfo,
 				 gboolean	 quote,
 				 gboolean	 to_all,
-				 gboolean	 ignore_replyto);
-void compose_forward		(MsgInfo	*msginfo,
-				 gboolean	 as_attach);
+				 gboolean	 ignore_replyto,
+				 const gchar	*body);
+void compose_forward		(GSList		*mlist,
+				 gboolean	 as_attach,
+				 const gchar	*body);
 void compose_reedit		(MsgInfo	*msginfo);
 
 GList *compose_get_compose_list	(void);
