@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2001 Hiroyuki Yamamoto
+ * Copyright (C) 1999-2002 Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -248,6 +248,28 @@ void gtkut_combo_set_items(GtkCombo *combo, const gchar *str1, ...)
 	g_list_free(combo_items);
 }
 
+gchar *gtkut_editable_get_selection(GtkEditable *editable)
+{
+	guint start_pos, end_pos;
+
+	g_return_val_if_fail(editable != NULL, NULL);
+
+	if (!editable->has_selection) return NULL;
+
+	if (editable->selection_start_pos == editable->selection_end_pos)
+		return NULL;
+
+	if (editable->selection_start_pos < editable->selection_end_pos) {
+		start_pos = editable->selection_start_pos;
+		end_pos = editable->selection_end_pos;
+	} else {
+		start_pos = editable->selection_end_pos;
+		end_pos = editable->selection_start_pos;
+	}
+
+	return gtk_editable_get_chars(editable, start_pos, end_pos);
+}
+
 /*
  * Walk through the widget tree and disclaim the selection from all currently
  * realized GtkEditable widgets.
@@ -361,6 +383,14 @@ gboolean gtkut_stext_is_uri_string(GtkSText *text,
 	return FALSE;
 }
 
+void gtk_stext_clear(GtkSText *text)
+{
+	gtk_stext_freeze(text);
+	gtk_stext_set_point(text, 0);
+	gtk_stext_forward_delete(text, gtk_stext_get_length(text));
+	gtk_stext_thaw(text);
+}
+
 void gtkut_widget_disable_theme_engine(GtkWidget *widget)
 {
 	GtkStyle *style, *new_style;
