@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999,2000 Hiroyuki Yamamoto
+ * Copyright (C) 1999-2002 Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -74,12 +74,12 @@ void imageview_show_image(ImageView *imageview, MimeInfo *mimeinfo,
 	GdkPixmap *pixmap;
 	GdkBitmap *mask;
 
+	imageview_clear(imageview);
+
 	pixbuf = gdk_pixbuf_new_from_file(file);
 
 	if (!pixbuf) {
 		g_warning(_("Can't load the image."));	
-		if (imageview->image)
-			gtk_widget_hide(imageview->image);
 		return;
 	}
 
@@ -111,12 +111,12 @@ void imageview_show_image(ImageView *imageview, MimeInfo *mimeinfo,
 {
 	GdkImlibImage *im;
 
+	imageview_clear(imageview);
+
 	im = gdk_imlib_load_image((gchar *)file);
 
 	if (!im) {
 		g_warning(_("Can't load the image."));	
-		if (imageview->image)
-			gtk_widget_hide(imageview->image);
 		return;
 	}
 
@@ -152,6 +152,20 @@ void imageview_show_image(ImageView *imageview, MimeInfo *mimeinfo,
 #endif /* HAVE_GDK_IMLIB */
 #endif /* HAVE_GDK_PIXBUF */
 
+void imageview_clear(ImageView *imageview)
+{
+	GtkAdjustment *hadj, *vadj;
+
+	if (imageview->image)
+		gtk_pixmap_set(GTK_PIXMAP(imageview->image), NULL, NULL);
+	hadj = gtk_scrolled_window_get_hadjustment
+		(GTK_SCROLLED_WINDOW(imageview->scrolledwin));
+	gtk_adjustment_set_value(hadj, 0.0);
+	vadj = gtk_scrolled_window_get_vadjustment
+		(GTK_SCROLLED_WINDOW(imageview->scrolledwin));
+	gtk_adjustment_set_value(vadj, 0.0);
+}
+
 void imageview_destroy(ImageView *imageview)
 {
 	g_free(imageview);
