@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2001 Hiroyuki Yamamoto
+ * Copyright (C) 1999-2002 Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -70,9 +70,11 @@ static GList *session_list = NULL;
 
 static gint imap_cmd_count = 0;
 
+static void imap_folder_init		(Folder		*folder,
+					 const gchar	*name,
+					 const gchar	*path);
+
 static IMAPSession *imap_session_get	(Folder		*folder);
-static gchar *imap_query_password	(const gchar	*server,
-					 const gchar	*user);
 
 static gint imap_scan_tree_recursive	(IMAPSession	*session,
 					 FolderItem	*item,
@@ -241,6 +243,45 @@ static gchar *search_array_str			(GPtrArray	*array,
 static void imap_path_separator_subst		(gchar		*str,
 						 gchar		 separator);
 
+
+Folder *imap_folder_new(const gchar *name, const gchar *path)
+{
+	Folder *folder;
+
+	folder = (Folder *)g_new0(IMAPFolder, 1);
+	imap_folder_init(folder, name, path);
+
+	return folder;
+}
+
+void imap_folder_destroy(IMAPFolder *folder)
+{
+	folder_remote_folder_destroy(REMOTE_FOLDER(folder));
+}
+
+static void imap_folder_init(Folder *folder, const gchar *name,
+			     const gchar *path)
+{
+	folder_remote_folder_init(folder, name, path);
+
+	folder->type = F_IMAP;
+
+	folder->get_msg_list        = imap_get_msg_list;
+	folder->fetch_msg           = imap_fetch_msg;
+	folder->add_msg             = imap_add_msg;
+	folder->move_msg            = imap_move_msg;
+	folder->move_msgs_with_dest = imap_move_msgs_with_dest;
+	folder->copy_msg            = imap_copy_msg;
+	folder->copy_msgs_with_dest = imap_copy_msgs_with_dest;
+	folder->remove_msg          = imap_remove_msg;
+	folder->remove_all_msg      = imap_remove_all_msg;
+	folder->scan                = imap_scan_folder;
+	folder->scan_tree           = imap_scan_tree;
+	folder->create_tree         = imap_create_tree;
+	folder->create_folder       = imap_create_folder;
+	folder->remove_folder       = imap_remove_folder;
+}
+
 static IMAPSession *imap_session_get(Folder *folder)
 {
 	RemoteFolder *rfolder = REMOTE_FOLDER(folder);
@@ -312,19 +353,6 @@ static IMAPSession *imap_session_get(Folder *folder)
 	return IMAP_SESSION(rfolder->session);
 }
 
-static gchar *imap_query_password(const gchar *server, const gchar *user)
-{
-	gchar *message;
-	gchar *pass;
-
-	message = g_strdup_printf(_("Input password for %s on %s:"),
-				  user, server);
-	pass = input_dialog_with_invisible(_("Input password"), message, NULL);
-	g_free(message);
-
-	return pass;
-}
-
 #if USE_SSL
 Session *imap_session_new(const gchar *server, gushort port,
 			  const gchar *user, const gchar *pass,
@@ -343,7 +371,7 @@ Session *imap_session_new(const gchar *server, gushort port,
 
 	if (!pass) {
 		gchar *tmp_pass;
-		tmp_pass = imap_query_password(server, user);
+		tmp_pass = input_dialog_query_password(server, user);
 		if (!tmp_pass)
 			return NULL;
 		Xstrdup_a(pass, tmp_pass, {g_free(tmp_pass); return NULL;});
@@ -539,6 +567,7 @@ gchar *imap_fetch_msg(Folder *folder, FolderItem *item, gint uid)
 gint imap_add_msg(Folder *folder, FolderItem *dest, const gchar *file,
 		  gboolean remove_source)
 {
+	gchar *destdir;
 	IMAPSession *session;
 	gint ok;
 
@@ -547,10 +576,12 @@ gint imap_add_msg(Folder *folder, FolderItem *dest, const gchar *file,
 	g_return_val_if_fail(file != NULL, -1);
 
 	session = imap_session_get(folder);
-	if (!session)
-		return -1;
+	if (!session) return -1;
+
+	destdir = imap_get_real_path(IMAP_FOLDER(folder), dest->path);
+	ok = imap_cmd_append(SESSION(session)->sock, destdir, file);
+	g_free(destdir);
 
-	ok = imap_cmd_append(SESSION(session)->sock, dest->path, file);
 	if (ok != IMAP_SUCCESS) {
 		g_warning(_("can't append message %s\n"), file);
 		return -1;
@@ -561,7 +592,7 @@ gint imap_add_msg(Folder *folder, FolderItem *dest, const gchar *file,
 			FILE_OP_ERROR(file, "unlink");
 	}
 
-	return dest->last_num;
+	return 0;
 }
 
 static gint imap_do_copy(Folder *folder, FolderItem *dest, MsgInfo *msginfo,
@@ -606,7 +637,10 @@ static gint imap_do_copy(Folder *folder, FolderItem *dest, MsgInfo *msginfo,
 	g_free(destdir);
 	statusbar_pop_all();
 
-	return ok;
+	if (ok == IMAP_SUCCESS)
+		return 0;
+	else
+		return -1;
 }
 
 static gint imap_do_copy_msgs_with_dest(Folder *folder, FolderItem *dest, 
@@ -617,7 +651,7 @@ static gint imap_do_copy_msgs_with_dest(Folder *folder, FolderItem *dest,
 	GSList *cur;
 	MsgInfo *msginfo;
 	IMAPSession *session;
-	gint ok;
+	gint ok = IMAP_SUCCESS;
 
 	g_return_val_if_fail(folder != NULL, -1);
 	g_return_val_if_fail(dest != NULL, -1);
@@ -661,29 +695,107 @@ static gint imap_do_copy_msgs_with_dest(Folder *folder, FolderItem *dest,
 	g_free(destdir);
 	statusbar_pop_all();
 
-	return IMAP_SUCCESS;
+	if (ok == IMAP_SUCCESS)
+		return 0;
+	else
+		return -1;
 }
 
 gint imap_move_msg(Folder *folder, FolderItem *dest, MsgInfo *msginfo)
 {
-	return imap_do_copy(folder, dest, msginfo, TRUE);
+	gchar *srcfile;
+	gint ret = 0;
+
+	g_return_val_if_fail(folder != NULL, -1);
+	g_return_val_if_fail(dest != NULL, -1);
+	g_return_val_if_fail(msginfo != NULL, -1);
+	g_return_val_if_fail(msginfo->folder != NULL, -1);
+
+	if (folder == msginfo->folder->folder)
+		return imap_do_copy(folder, dest, msginfo, TRUE);
+
+	srcfile = procmsg_get_message_file(msginfo);
+	if (!srcfile) return -1;
+
+	ret = imap_add_msg(folder, dest, srcfile, FALSE);
+	g_free(srcfile);
+
+	if (ret == 0)
+		ret = folder_item_remove_msg(msginfo->folder, msginfo->msgnum);
+
+	return ret;
 }
 
 gint imap_move_msgs_with_dest(Folder *folder, FolderItem *dest, 
 			      GSList *msglist)
 {
-	return imap_do_copy_msgs_with_dest(folder, dest, msglist, TRUE);
+	MsgInfo *msginfo;
+	GSList *cur;
+	gint ret = 0;
+
+	g_return_val_if_fail(folder != NULL, -1);
+	g_return_val_if_fail(dest != NULL, -1);
+	g_return_val_if_fail(msglist != NULL, -1);
+
+	msginfo = (MsgInfo *)msglist->data;
+	if (folder == msginfo->folder->folder)
+		return imap_do_copy_msgs_with_dest(folder, dest, msglist, TRUE);
+
+	for (cur = msglist; cur != NULL; cur = cur->next) {
+		msginfo = (MsgInfo *)cur->data;
+		ret = imap_move_msg(folder, dest, msginfo);
+		if (ret != 0) break;
+	}
+
+	return ret;
 }
 
 gint imap_copy_msg(Folder *folder, FolderItem *dest, MsgInfo *msginfo)
 {
-	return imap_do_copy(folder, dest, msginfo, FALSE);
+	gchar *srcfile;
+	gint ret = 0;
+
+	g_return_val_if_fail(folder != NULL, -1);
+	g_return_val_if_fail(dest != NULL, -1);
+	g_return_val_if_fail(msginfo != NULL, -1);
+	g_return_val_if_fail(msginfo->folder != NULL, -1);
+
+	if (folder == msginfo->folder->folder)
+		return imap_do_copy(folder, dest, msginfo, FALSE);
+
+	srcfile = procmsg_get_message_file(msginfo);
+	if (!srcfile) return -1;
+
+	ret = imap_add_msg(folder, dest, srcfile, FALSE);
+
+	g_free(srcfile);
+
+	return ret;
 }
 
 gint imap_copy_msgs_with_dest(Folder *folder, FolderItem *dest, 
 			      GSList *msglist)
 {
-	return imap_do_copy_msgs_with_dest(folder, dest, msglist, FALSE);
+	MsgInfo *msginfo;
+	GSList *cur;
+	gint ret = 0;
+
+	g_return_val_if_fail(folder != NULL, -1);
+	g_return_val_if_fail(dest != NULL, -1);
+	g_return_val_if_fail(msglist != NULL, -1);
+
+	msginfo = (MsgInfo *)msglist->data;
+	if (folder == msginfo->folder->folder)
+		return imap_do_copy_msgs_with_dest
+			(folder, dest, msglist, FALSE);
+
+	for (cur = msglist; cur != NULL; cur = cur->next) {
+		msginfo = (MsgInfo *)cur->data;
+		ret = imap_copy_msg(folder, dest, msginfo);
+		if (ret != 0) break;
+	}
+
+	return ret;
 }
 
 gint imap_remove_msg(Folder *folder, FolderItem *item, gint uid)
@@ -2207,19 +2319,48 @@ static gint imap_cmd_append(SockInfo *sock, const gchar *destfolder,
 	gint ok;
 	gint size;
 	gchar *destfolder_;
+	gchar buf[BUFFSIZE];
+	FILE *fp;
 
 	g_return_val_if_fail(file != NULL, IMAP_ERROR);
 
-	size = get_file_size(file);
+	size = get_file_size_as_crlf(file);
+	if ((fp = fopen(file, "r")) == NULL) {
+		FILE_OP_ERROR(file, "fopen");
+		return -1;
+	}
 	QUOTE_IF_REQUIRED(destfolder_, destfolder);
-	imap_cmd_gen_send(sock, "APPEND %s {%d}", destfolder_, size);
-	ok = imap_cmd_ok(sock, NULL);
-	if (ok != IMAP_SUCCESS) {
+	imap_cmd_gen_send(sock, "APPEND %s (\\Seen) {%d}", destfolder_, size);
+
+	ok = imap_cmd_gen_recv(sock, buf, sizeof(buf));
+	if (ok != IMAP_SUCCESS || buf[0] != '+' || buf[1] != ' ') {
 		log_warning(_("can't append %s to %s\n"), file, destfolder_);
+		fclose(fp);
+		return IMAP_ERROR;
+	}
+
+	log_print("IMAP4> %s\n", _("(sending file...)"));
+
+	while (fgets(buf, sizeof(buf), fp) != NULL) {
+		strretchomp(buf);
+		if (sock_puts(sock, buf) < 0) {
+			fclose(fp);
+			sock_close(sock);
+			return -1;
+		}
+	}
+
+	if (ferror(fp)) {
+		FILE_OP_ERROR(file, "fgets");
+		fclose(fp);
+		sock_close(sock);
 		return -1;
 	}
 
-	return ok;
+	sock_puts(sock, "");
+
+	fclose(fp);
+	return imap_cmd_ok(sock, NULL);
 }
 
 static gint imap_cmd_copy(SockInfo *sock, guint32 uid, const gchar *destfolder)
