@@ -462,9 +462,8 @@ static void imp_ldif_file_select( void ) {
 	gtk_grab_add( _imp_ldif_file_selector_.fileSelector );
 }
 
-static gint imp_ldif_delete_event( GtkWidget *widget, GdkEventAny *event, gboolean *cancelled ) {
-	*cancelled = TRUE;
-	gtk_main_quit();
+static gint imp_ldif_delete_event( GtkWidget *widget, GdkEventAny *event, gpointer data ) {
+	imp_ldif_cancel( widget, data );
 	return TRUE;
 }
 
@@ -552,10 +551,13 @@ static void imp_ldif_page_fields( gint pageNum, gchar *pageLbl ) {
 	GtkWidget *check_select;
 	gint top;
 
-	gchar *titles[ FIELDS_N_COLS ] =
-		{ _("S"), _("LDIF Field"), _("Attribute Name") };
+	gchar *titles[ FIELDS_N_COLS ];
 	gint i;
 
+	titles[ FIELD_COL_SELECT ] = _("S");
+	titles[ FIELD_COL_FIELD  ] = _("LDIF Field");
+	titles[ FIELD_COL_ATTRIB ] = _("Attribute Name");
+
 	vbox = gtk_vbox_new(FALSE, 8);
 	gtk_container_add( GTK_CONTAINER( impldif_dlg.notebook ), vbox );
 	gtk_container_set_border_width( GTK_CONTAINER (vbox), 4 );
