@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999,2000 Hiroyuki Yamamoto
+ * Copyright (C) 1999-2002 Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,21 +30,31 @@
 #include "manual.h"
 #include "utils.h"
 
+static gchar *get_lang_str(ManualLang lang);
+
+static gchar *get_lang_str(ManualLang lang)
+{
+	switch (lang) {
+	case MANUAL_LANG_EN:
+		return "en";
+	case MANUAL_LANG_ES:
+		return "es";
+	case MANUAL_LANG_FR:
+		return "fr";
+	case MANUAL_LANG_JA:
+		return "ja";
+	default:
+		return NULL;
+	}
+}
+
 void manual_open(ManualLang lang)
 {
 	gchar *lang_str;
 	gchar *file_uri;
 
-	switch (lang) {
-	case MANUAL_LANG_EN:
-		lang_str = "en";
-		break;
-	case MANUAL_LANG_JA:
-		lang_str = "ja";
-		break;
-	default:
-		return;
-	}
+	lang_str = get_lang_str(lang);
+	if (!lang_str) return;
 
 	file_uri = g_strconcat("file://", MANUALDIR,
 			       G_DIR_SEPARATOR_S, lang_str, G_DIR_SEPARATOR_S,
@@ -53,3 +63,19 @@ void manual_open(ManualLang lang)
 	open_uri(file_uri, prefs_common.uri_cmd);
 	g_free(file_uri);
 }
+
+void faq_open(ManualLang lang)
+{
+	gchar *lang_str;
+	gchar *file_uri;
+
+	lang_str = get_lang_str(lang);
+	if (!lang_str) return;
+
+	file_uri = g_strconcat("file://", FAQDIR,
+			       G_DIR_SEPARATOR_S, lang_str, G_DIR_SEPARATOR_S,
+			       FAQ_HTML_INDEX, NULL);
+	debug_print("Opening FAQ: %s\n", file_uri);
+	open_uri(file_uri, prefs_common.uri_cmd);
+	g_free(file_uri);
+}
