@@ -213,7 +213,7 @@ gint proc_mbox(FolderItem *dest, const gchar *mbox, GHashTable *folder_table)
 		} else
 			dropfolder = dest;
 
-		if (folder_item_add_msg(dropfolder, tmp_file) < 0) {
+		if (folder_item_add_msg(dropfolder, tmp_file, TRUE) < 0) {
 			fclose(mbox_fp);
 			unlink(tmp_file);
 			return -1;
