@@ -102,7 +102,7 @@ void prefs_config_parse_one_line(PrefParam *param, const gchar *buf)
 		if (buf[name_len] != '=')
 			continue;
 		value = buf + name_len + 1;
-		debug_print("%s = %s\n", param[i].name, value);
+		/* debug_print("%s = %s\n", param[i].name, value); */
 
 		switch (param[i].type) {
 		case P_STRING:
@@ -128,6 +128,7 @@ void prefs_config_parse_one_line(PrefParam *param, const gchar *buf)
 				(gushort)atoi(value);
 			break;
 		default:
+			break;
 		}
 	}
 }
@@ -409,6 +410,7 @@ void prefs_set_default(PrefParam *param)
 				*((gushort *)param[i].data) = 0;
 			break;
 		default:
+			break;
 		}
 	}
 }
@@ -427,6 +429,7 @@ void prefs_free(PrefParam *param)
 			g_free(*((gchar **)param[i].data));
 			break;
 		default:
+			break;
 		}
 	}
 }
@@ -570,6 +573,7 @@ void prefs_set_dialog_to_default(PrefParam *param)
 			tmpparam.data = &enum_data;
 			break;
 		case P_OTHER:
+			break;
 		}
 		tmpparam.widget_set_func(&tmpparam);
 		g_free(str_data);
