@@ -870,7 +870,8 @@ gchar *procmime_get_mime_type(const gchar *filename)
 {
 	static GHashTable *mime_type_table = NULL;
 	MimeType *mime_type;
-	const gchar *ext, *p;
+	const gchar *p;
+	gchar *ext;
 
 	if (!mime_type_table) {
 		mime_type_table = procmime_get_mime_type_table();
@@ -879,11 +880,10 @@ gchar *procmime_get_mime_type(const gchar *filename)
 
 	filename = g_basename(filename);
 	p = strrchr(filename, '.');
-	if (p)
-		ext = p + 1;
-	else
-		return NULL;
+	if (!p) return NULL;
 
+	Xstrdup_a(ext, p + 1, return NULL);
+	g_strdown(ext);
 	mime_type = g_hash_table_lookup(mime_type_table, ext);
 	if (mime_type) {
 		gchar *str;
@@ -937,6 +937,8 @@ static GHashTable *procmime_get_mime_type_table(void)
 
 		exts = g_strsplit(mime_type->extension, " ", 16);
 		for (i = 0; exts[i] != NULL; i++) {
+			/* make the key case insensitive */
+			g_strdown(exts[i]);
 			/* use previously dup'd key on overwriting */
 			if (g_hash_table_lookup(table, exts[i]))
 				key = exts[i];
