@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999,2000 Hiroyuki Yamamoto
+ * Copyright (C) 1999-2001 Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,6 +27,7 @@
 #include <gtk/gtkhbox.h>
 #include <gtk/gtklabel.h>
 #include <gtk/gtkprogressbar.h>
+#include <gtk/gtkscrolledwindow.h>
 #include <gtk/gtkbutton.h>
 
 #include "intl.h"
@@ -44,6 +45,7 @@ ProgressDialog *progress_dialog_create(void)
 	GtkWidget *cancel_btn;
 	GtkWidget *cancel_area;
 	GtkWidget *progressbar;
+	GtkWidget *scrolledwin;
 	GtkWidget *clist;
 	gchar *text[] = {NULL, NULL, NULL};
 
@@ -57,15 +59,15 @@ ProgressDialog *progress_dialog_create(void)
 	gtk_widget_set_usize(window, 450, -1);
 	gtk_container_set_border_width(GTK_CONTAINER(window), 8);
 	gtk_window_set_position(GTK_WINDOW(window), GTK_WIN_POS_CENTER);
-	gtk_window_set_modal(GTK_WINDOW(window), TRUE);
 	gtk_window_set_policy(GTK_WINDOW(window), FALSE, TRUE, TRUE);
+	gtk_widget_realize(window);
 
 	vbox = gtk_vbox_new(FALSE, 8);
 	gtk_container_add(GTK_CONTAINER(window), vbox);
 	gtk_widget_show(vbox);
 
 	hbox = gtk_hbox_new(FALSE, 0);
-	gtk_box_pack_start(GTK_BOX(vbox), hbox, TRUE, TRUE, 8);
+	gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 8);
 	gtk_widget_show(hbox);
 
 	label = gtk_label_new("");
@@ -82,9 +84,16 @@ ProgressDialog *progress_dialog_create(void)
 	gtk_box_pack_start(GTK_BOX(vbox), progressbar, FALSE, FALSE, 0);
 	gtk_widget_show(progressbar);
 
+	scrolledwin = gtk_scrolled_window_new(NULL, NULL);
+	gtk_widget_show(scrolledwin);
+	gtk_box_pack_start(GTK_BOX(vbox), scrolledwin, TRUE, TRUE, 0);
+	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolledwin),
+				       GTK_POLICY_AUTOMATIC,
+				       GTK_POLICY_AUTOMATIC);
+
 	clist = gtk_clist_new_with_titles(3, text);
 	gtk_widget_show(clist);
-	gtk_box_pack_start(GTK_BOX(vbox), clist, TRUE, TRUE, 0);
+	gtk_container_add(GTK_CONTAINER(scrolledwin), clist);
 	gtk_widget_set_usize(clist, -1, 120);
 	gtk_clist_set_column_justification(GTK_CLIST(clist), 0,
 					   GTK_JUSTIFY_CENTER);
