@@ -69,6 +69,7 @@ struct passphrase_cb_info_s {
 
 static char *create_boundary (void);
 
+#if 0
 static void dump_mimeinfo (const char *text, MimeInfo *x)
 {
     g_message ("** MimeInfo[%s] %p  level=%d",
@@ -108,6 +109,7 @@ static void dump_part ( MimeInfo *mimeinfo, FILE *fp )
         g_warning ("dump_part: read error");
     g_message ("** --- end dump_part ----");
 }
+#endif
 
 void
 rfc2015_disable_all (void)
@@ -302,14 +304,14 @@ static void check_signature (MimeInfo *mimeinfo, MimeInfo *partinfo, FILE *fp)
 	err = gpgme_data_new_from_filepart (&sig, NULL, fp,
 					    partinfo->fpos, partinfo->size);
     if (err) {
-        g_message ("gpgme_data_new_from_filepart failed: %s",
+        g_warning ("gpgme_data_new_from_filepart failed: %s",
 		   gpgme_strerror (err));
         goto leave;
     }
 
     err = gpgme_op_verify (ctx, sig, text, &status);
     if (err) 
-        g_message ("gpgme_op_verify failed: %s", gpgme_strerror (err));
+        g_warning ("gpgme_op_verify failed: %s", gpgme_strerror (err));
 
     /* FIXME: check what the heck this sig_status_full stuff is.
      * it should better go into sigstatus.c */
@@ -334,26 +336,26 @@ leave:
 }
 
 static const char *
-passphrase_cb (void *opaque, const char *desc, void *r_hd)
+passphrase_cb (void *opaque, const char *desc, void **r_hd)
 {
     struct passphrase_cb_info_s *info = opaque;
     GpgmeCtx ctx = info ? info->c : NULL;
     const char *pass;
 
     if (!desc) {
-        /* FIXME: cleanup by looking at *r_hd */
+        /* FIXME: cleanup by looking at **r_hd */
         return NULL;
     }
 
     gpgmegtk_set_passphrase_grab (prefs_common.passphrase_grab);
-    g_message ("%% requesting passphrase for `%s': ", desc );
+    debug_print ("%% requesting passphrase for `%s': ", desc );
     pass = gpgmegtk_passphrase_mbox (desc);
     if (!pass) {
-        g_message ("%% cancel passphrase entry");
+        debug_print ("%% cancel passphrase entry");
         gpgme_cancel (ctx);
     }
     else
-        g_message ("%% sending passphrase");
+        debug_print ("%% sending passphrase");
 
     return pass;
 }
@@ -362,6 +364,7 @@ passphrase_cb (void *opaque, const char *desc, void *r_hd)
  * Copy a gpgme data object to a temporary file and
  * return this filename 
  */
+#if 0
 static char *
 copy_gpgmedata_to_temp (GpgmeData data, guint *length)
 {
@@ -383,20 +386,21 @@ copy_gpgmedata_to_temp (GpgmeData data, guint *length)
 
     err = gpgme_data_rewind ( data );
     if (err)
-        g_message ("** gpgme_data_rewind failed: %s", gpgme_strerror (err));
+        g_warning ("gpgme_data_rewind failed: %s", gpgme_strerror (err));
 
     while (!(err = gpgme_data_read (data, buf, 100, &nread))) {
         fwrite ( buf, nread, 1, fp );
     }
 
     if (err != GPGME_EOF)
-        g_warning ("** gpgme_data_read failed: %s", gpgme_strerror (err));
+        g_warning ("gpgme_data_read failed: %s", gpgme_strerror (err));
 
     fclose (fp);
     *length = nread;
 
     return tmp;
 }
+#endif
 
 static GpgmeData
 pgp_decrypt (MimeInfo *partinfo, FILE *fp)
@@ -410,21 +414,21 @@ pgp_decrypt (MimeInfo *partinfo, FILE *fp)
 
     err = gpgme_new (&ctx);
     if (err) {
-        g_message ("gpgme_new failed: %s", gpgme_strerror (err));
+        g_warning ("gpgme_new failed: %s", gpgme_strerror (err));
         goto leave;
     }
 
     err = gpgme_data_new_from_filepart (&cipher, NULL, fp,
 					partinfo->fpos, partinfo->size);
     if (err) {
-        g_message ("gpgme_data_new_from_filepart failed: %s",
+        g_warning ("gpgme_data_new_from_filepart failed: %s",
                    gpgme_strerror (err));
         goto leave;
     }
 
     err = gpgme_data_new (&plain);
     if (err) {
-        g_message ("gpgme_new failed: %s", gpgme_strerror (err));
+        g_warning ("gpgme_new failed: %s", gpgme_strerror (err));
         goto leave;
     }
 
@@ -438,12 +442,12 @@ pgp_decrypt (MimeInfo *partinfo, FILE *fp)
 leave:
     gpgme_data_release (cipher);
     if (err) {
-        g_warning ("** decryption failed: %s", gpgme_strerror (err));
+        g_warning ("decryption failed: %s", gpgme_strerror (err));
         gpgme_data_release (plain);
         plain = NULL;
     }
     else
-        g_message ("** decryption succeeded");
+        debug_print ("** decryption succeeded");
 
     gpgme_release (ctx);
     return plain;
@@ -459,7 +463,7 @@ MimeInfo * rfc2015_find_signature (MimeInfo *mimeinfo)
     if (g_strcasecmp (mimeinfo->content_type, "multipart/signed"))
         return NULL;
 
-    g_message ("** multipart/signed encountered");
+    debug_print ("** multipart/signed encountered");
 
     /* check that we have at least 2 parts of the correct type */
     for (partinfo = mimeinfo->children;
@@ -547,12 +551,18 @@ headerp(char *p, char **names)
 }
 
 
+#define DECRYPTION_ABORT() \
+{ \
+    procmime_mimeinfo_free_all(tmpinfo); \
+    msginfo->decryption_failed = 1; \
+    return; \
+}
+
 void rfc2015_decrypt_message (MsgInfo *msginfo, MimeInfo *mimeinfo, FILE *fp)
 {
     static int id;
-    MimeInfo *partinfo;
-    int n, found;
-    int ver_okay=0;
+    MimeInfo *tmpinfo, *partinfo;
+    int ver_ok = 0;
     char *fname;
     GpgmeData plain;
     FILE *dstfp;
@@ -560,61 +570,60 @@ void rfc2015_decrypt_message (MsgInfo *msginfo, MimeInfo *mimeinfo, FILE *fp)
     char buf[BUFFSIZE];
     GpgmeError err;
 
+    g_return_if_fail (msginfo != NULL);
+    g_return_if_fail (mimeinfo != NULL);
+    g_return_if_fail (fp != NULL);
     g_return_if_fail (mimeinfo->mime_type == MIME_MULTIPART);
 
-    g_message ("** multipart/encrypted encountered");
+    debug_print ("** decrypting multipart/encrypted message");
 
     /* skip headers */
     if (fseek(fp, mimeinfo->fpos, SEEK_SET) < 0)
         perror("fseek");
-    while (fgets(buf, sizeof(buf), fp) != NULL)
-        if (buf[0] == '\r' || buf[0] == '\n') break;
-    
-    procmime_scan_multipart_message(mimeinfo, fp);
+    tmpinfo = procmime_scan_mime_header(fp);
+    if (!tmpinfo || tmpinfo->mime_type != MIME_MULTIPART) {
+        DECRYPTION_ABORT();
+    }
+
+    procmime_scan_multipart_message(tmpinfo, fp);
 
     /* check that we have the 2 parts */
-    n = found = 0;
-    for (partinfo = mimeinfo->children; partinfo; partinfo = partinfo->next) {
-        if (++n == 1 && !g_strcasecmp (partinfo->content_type,
-				       "application/pgp-encrypted")) {
-            /* Fixme: check that the version is 1 */
-            ver_okay = 1;
-        }
-        else if (n == 2 && !g_strcasecmp (partinfo->content_type,
-					  "application/octet-stream")) {
-            if (partinfo->next)
-                g_warning ("** oops: pgp_encrypted with more than 2 parts");
-            break;
-        }
+    partinfo = tmpinfo->children;
+    if (!partinfo || !partinfo->next) {
+        DECRYPTION_ABORT();
+    }
+    if (!g_strcasecmp (partinfo->content_type, "application/pgp-encrypted")) {
+        /* Fixme: check that the version is 1 */
+        ver_ok = 1;
+    }
+    partinfo = partinfo->next;
+    if (ver_ok &&
+        !g_strcasecmp (partinfo->content_type, "application/octet-stream")) {
+        if (partinfo->next)
+            g_warning ("oops: pgp_encrypted with more than 2 parts");
+    }
+    else {
+        DECRYPTION_ABORT();
     }
 
-    if (!ver_okay || !partinfo) {
-        msginfo->decryption_failed = 1;
-        /* fixme: remove the stuff, that the above procmime_scan_multiparts() 
-         * has appended to mimeino */
-        return;
-    }
-
-    g_message ("** yep, it is pgp encrypted");
+    debug_print ("** yep, it is pgp encrypted");
 
     plain = pgp_decrypt (partinfo, fp);
     if (!plain) {
-        msginfo->decryption_failed = 1;
-        return;
+        DECRYPTION_ABORT();
     }
-    
+
     fname = g_strdup_printf("%s%cplaintext.%08x",
 			    get_mime_tmp_dir(), G_DIR_SEPARATOR, ++id);
 
     if ((dstfp = fopen(fname, "w")) == NULL) {
         FILE_OP_ERROR(fname, "fopen");
         g_free(fname);
-        msginfo->decryption_failed = 1;
-        return;
+        DECRYPTION_ABORT();
     }
 
     /* write the orginal header to the new file */
-    if (fseek(fp, mimeinfo->fpos, SEEK_SET) < 0)
+    if (fseek(fp, tmpinfo->fpos, SEEK_SET) < 0)
         perror("fseek");
 
     while (fgets(buf, sizeof(buf), fp)) {
@@ -627,24 +636,27 @@ void rfc2015_decrypt_message (MsgInfo *msginfo, MimeInfo *mimeinfo, FILE *fp)
 
     err = gpgme_data_rewind (plain);
     if (err)
-        g_message ("** gpgme_data_rewind failed: %s", gpgme_strerror (err));
+        g_warning ("gpgme_data_rewind failed: %s", gpgme_strerror (err));
 
     while (!(err = gpgme_data_read (plain, buf, sizeof(buf), &nread))) {
         fwrite (buf, nread, 1, dstfp);
     }
 
     if (err != GPGME_EOF) {
-        g_warning ("** gpgme_data_read failed: %s", gpgme_strerror (err));
+        g_warning ("gpgme_data_read failed: %s", gpgme_strerror (err));
     }
 
     fclose (dstfp);
+    procmime_mimeinfo_free_all(tmpinfo);
 
     msginfo->plaintext_file = fname;
     msginfo->decryption_failed = 0;
 }
 
+#undef DECRYPTION_ABORT
 
-/* 
+
+/*
  * plain contains an entire mime object.
  * Encrypt it and return an GpgmeData object with the encrypted version of
  * the file or NULL in case of error.
@@ -665,12 +677,12 @@ pgp_encrypt ( GpgmeData plain, GpgmeRecipients rset )
     }
 
     if (err) {
-        g_warning ("** encryption failed: %s", gpgme_strerror (err));
+        g_warning ("encryption failed: %s", gpgme_strerror (err));
         gpgme_data_release (cipher);
         cipher = NULL;
     }
     else {
-        g_message ("** encryption succeeded");
+        debug_print ("** encryption succeeded");
     }
 
     gpgme_release (ctx);
@@ -715,7 +727,7 @@ rfc2015_encrypt (const char *file, GSList *recp_list)
     if (!err)
 	err = gpgme_data_new (&plain);
     if (err) {
-        g_message ("gpgme_data_new failed: %s", gpgme_strerror (err));
+        g_warning ("gpgme_data_new failed: %s", gpgme_strerror (err));
         goto failure;
     }
 
@@ -726,7 +738,7 @@ rfc2015_encrypt (const char *file, GSList *recp_list)
         /* fixme: check for overlong lines */
         if (headerp (buf, content_names)) {
             if (clineidx >= DIM (clines)) {
-                g_message ("rfc2015_encrypt: too many content lines");
+                g_warning ("rfc2015_encrypt: too many content lines");
                 goto failure;
             }
             clines[clineidx++] = g_strdup (buf);
@@ -757,7 +769,7 @@ rfc2015_encrypt (const char *file, GSList *recp_list)
 
     /* write them to the temp data and add the rest of the message */
     for (i = 0; !err && i < clineidx; i++) {
-        g_message ("%% %s:%d: cline=`%s'", __FILE__ ,__LINE__, clines[i]);
+        debug_print ("%% %s:%d: cline=`%s'", __FILE__ ,__LINE__, clines[i]);
         err = gpgme_data_write (plain, clines[i], strlen (clines[i]));
     }
     if (!err)
@@ -770,7 +782,7 @@ rfc2015_encrypt (const char *file, GSList *recp_list)
         goto failure;
     }
     if (err) {
-        g_warning ("** gpgme_data_write failed: %s", gpgme_strerror (err));
+        g_warning ("gpgme_data_write failed: %s", gpgme_strerror (err));
         goto failure;
     }
 
@@ -803,14 +815,14 @@ rfc2015_encrypt (const char *file, GSList *recp_list)
     /* Write the header, append new content lines, part 1 and part 2 header */
     err = gpgme_data_rewind (header);
     if (err) {
-        g_message ("gpgme_data_rewind failed: %s", gpgme_strerror (err));
+        g_warning ("gpgme_data_rewind failed: %s", gpgme_strerror (err));
         goto failure;
     }
     while (!(err = gpgme_data_read (header, buf, BUFFSIZE, &nread))) {
         fwrite (buf, nread, 1, fp);
     }
     if (err != GPGME_EOF) {
-        g_warning ("** gpgme_data_read failed: %s", gpgme_strerror (err));
+        g_warning ("gpgme_data_read failed: %s", gpgme_strerror (err));
         goto failure;
     }
     if (ferror (fp)) {
@@ -840,7 +852,7 @@ rfc2015_encrypt (const char *file, GSList *recp_list)
     /* append the encrypted stuff */
     err = gpgme_data_rewind (cipher);
     if (err) {
-        g_warning ("** gpgme_data_rewind on cipher failed: %s",
+        g_warning ("gpgme_data_rewind on cipher failed: %s",
                    gpgme_strerror (err));
         goto failure;
     }
@@ -849,7 +861,7 @@ rfc2015_encrypt (const char *file, GSList *recp_list)
         fwrite (buf, nread, 1, fp);
     }
     if (err != GPGME_EOF) {
-        g_warning ("** gpgme_data_read failed: %s", gpgme_strerror (err));
+        g_warning ("gpgme_data_read failed: %s", gpgme_strerror (err));
         goto failure;
     }
 
@@ -931,7 +943,7 @@ set_signers (GpgmeCtx ctx, PrefsAccount *ac)
 
 leave:
     if (err)
-        g_message ("** set_signers failed: %s", gpgme_strerror (err));
+        g_warning ("set_signers failed: %s", gpgme_strerror (err));
     for (p = key_list; p != NULL; p = p->next)
 	gpgme_key_unref ((GpgmeKey) p->data);
     g_slist_free (key_list);
@@ -974,12 +986,12 @@ pgp_sign (GpgmeData plain, PrefsAccount *ac)
 
 leave:
     if (err) {
-        g_message ("** signing failed: %s", gpgme_strerror (err));
+        g_warning ("signing failed: %s", gpgme_strerror (err));
         gpgme_data_release (sig);
         sig = NULL;
     }
     else {
-        g_message ("** signing succeeded");
+        debug_print ("** signing succeeded");
     }
 
     gpgme_release (ctx);
@@ -1014,7 +1026,7 @@ rfc2015_sign (const char *file, PrefsAccount *ac)
     if (!err)
         err = gpgme_data_new (&plain);
     if (err) {
-        g_message ("gpgme_data_new failed: %s", gpgme_strerror (err));
+        g_warning ("gpgme_data_new failed: %s", gpgme_strerror (err));
         goto failure;
     }
 
@@ -1025,7 +1037,7 @@ rfc2015_sign (const char *file, PrefsAccount *ac)
         /* fixme: check for overlong lines */
         if (headerp (buf, content_names)) {
             if (clineidx >= DIM (clines)) {
-                g_message ("rfc2015_sign: too many content lines");
+                g_warning ("rfc2015_sign: too many content lines");
                 goto failure;
             }
             clines[clineidx++] = g_strdup (buf);
@@ -1068,7 +1080,7 @@ rfc2015_sign (const char *file, PrefsAccount *ac)
         goto failure;
     }
     if (err) {
-        g_message ("** gpgme_data_write failed: %s", gpgme_strerror (err));
+        g_warning ("gpgme_data_write failed: %s", gpgme_strerror (err));
         goto failure;
     }
 
@@ -1092,12 +1104,12 @@ rfc2015_sign (const char *file, PrefsAccount *ac)
     /* Write the rfc822 header and add new content lines */
     err = gpgme_data_rewind (header);
     if (err)
-        g_message ("** gpgme_data_rewind failed: %s", gpgme_strerror (err));
+        g_warning ("gpgme_data_rewind failed: %s", gpgme_strerror (err));
     while (!(err = gpgme_data_read (header, buf, BUFFSIZE, &nread))) {
         fwrite (buf, nread, 1, fp);
     }
     if (err != GPGME_EOF) {
-        g_message ("** gpgme_data_read failed: %s", gpgme_strerror (err));
+        g_warning ("gpgme_data_read failed: %s", gpgme_strerror (err));
         goto failure;
     }
     if (ferror (fp)) {
@@ -1117,7 +1129,7 @@ rfc2015_sign (const char *file, PrefsAccount *ac)
     fprintf (fp, "\r\n--%s\r\n", boundary);
     err = gpgme_data_rewind (plain);
     if (err) {
-        g_message ("** gpgme_data_rewind on plain failed: %s",
+        g_warning ("gpgme_data_rewind on plain failed: %s",
                    gpgme_strerror (err));
         goto failure;
     }
@@ -1125,7 +1137,7 @@ rfc2015_sign (const char *file, PrefsAccount *ac)
         fwrite (buf, nread, 1, fp);   
     }
     if (err != GPGME_EOF) {
-        g_message ("** gpgme_data_read failed: %s", gpgme_strerror (err));
+        g_warning ("gpgme_data_read failed: %s", gpgme_strerror (err));
         goto failure;
     }
 
@@ -1136,7 +1148,7 @@ rfc2015_sign (const char *file, PrefsAccount *ac)
 
     err = gpgme_data_rewind (sigdata);
     if (err) {
-        g_message ("** gpgme_data_rewind on sigdata failed: %s",
+        g_warning ("gpgme_data_rewind on sigdata failed: %s",
                    gpgme_strerror (err));
         goto failure;
     }
@@ -1145,7 +1157,7 @@ rfc2015_sign (const char *file, PrefsAccount *ac)
         fwrite (buf, nread, 1, fp);
     }
     if (err != GPGME_EOF) {
-        g_message ("** gpgme_data_read failed: %s", gpgme_strerror (err));
+        g_warning ("gpgme_data_read failed: %s", gpgme_strerror (err));
         goto failure;
     }
 
