@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999,2000 Hiroyuki Yamamoto
+ * Copyright (C) 1999-2001 Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,8 +24,9 @@
 
 #include "prefs_account.h"
 
-gint send_message	(const gchar *file, PrefsAccount *ac_prefs,
-			 GSList *to_list);
-gint send_message_queue	(const gchar *file);
+gint send_message		(const gchar	*file,
+				 PrefsAccount	*ac_prefs,
+				 GSList		*to_list);
+gint send_message_queue		(const gchar	*file);
 
 #endif /* __SEND_H__ */
