@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2001 Hiroyuki Yamamoto
+ * Copyright (C) 1999-2002 Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -34,7 +34,8 @@ typedef struct _SummaryColumnState	SummaryColumnState;
 #include "folderview.h"
 #include "headerview.h"
 #include "messageview.h"
-#include "headerwindow.h"
+#include "compose.h"
+#include "prefs_filter.h"
 #include "folder.h"
 #include "gtksctree.h"
 
@@ -125,7 +126,6 @@ struct _SummaryView
 	FolderView   *folderview;
 	HeaderView   *headerview;
 	MessageView  *messageview;
-	HeaderWindow *headerwin;
 
 	FolderItem *folder_item;
 
@@ -179,12 +179,16 @@ void summary_select_by_msgnum	  (SummaryView		*summaryview,
 				   guint		 msgnum);
 void summary_select_node	  (SummaryView		*summaryview,
 				   GtkCTreeNode		*node,
-				   gboolean		 display_msg);
+				   gboolean		 display_msg,
+				   gboolean		 do_refresh);
 
 void summary_thread_build	  (SummaryView		*summaryview);
 void summary_unthread		  (SummaryView		*summaryview);
 
 void summary_filter		  (SummaryView		*summaryview);
+void summary_filter_open	  (SummaryView		*summaryview,
+				   PrefsFilterType	 type);
+
 void summary_sort		  (SummaryView		*summaryview,
 				   SummarySortType	 type);
 
@@ -200,12 +204,15 @@ gint summary_write_cache	  (SummaryView		*summaryview);
 void summary_pass_key_press_event (SummaryView		*summaryview,
 				   GdkEventKey		*event);
 
+void summary_display_msg_selected (SummaryView		*summaryview,
+				   gboolean		 all_headers);
 void summary_redisplay_msg	  (SummaryView		*summaryview);
 void summary_open_msg		  (SummaryView		*summaryview);
 void summary_view_source	  (SummaryView		*summaryview);
 void summary_reedit		  (SummaryView		*summaryview);
 void summary_step		  (SummaryView		*summaryview,
 				   GtkScrollType	 type);
+void summary_toggle_view	  (SummaryView		*summaryview);
 void summary_set_marks_selected	  (SummaryView		*summaryview);
 
 void summary_move_selected_to	  (SummaryView		*summaryview,
@@ -225,6 +232,9 @@ void summary_add_address	  (SummaryView		*summaryview);
 void summary_select_all		  (SummaryView		*summaryview);
 void summary_unselect_all	  (SummaryView		*summaryview);
 
+void summary_reply		  (SummaryView		*summaryview,
+				   ComposeMode		 mode);
+
 void summary_set_colorlabel	  (SummaryView		*summaryview,
 				   guint		 labelcolor,
 				   GtkWidget		*widget);
