@@ -35,7 +35,7 @@
 #include <ldap.h>
 #include <lber.h>
 #include <pthread.h>
-#include <dlfcn.h>
+/* #include <dlfcn.h> */
 
 #include "mgutils.h"
 #include "addritem.h"
@@ -675,7 +675,7 @@ gint syldap_read_data( SyldapServer *ldapServer ) {
 		/* TODO: really necessary to call gdk_threads_XXX()??? gtk_idle_add()
 		 * should do this - could someone check the GTK sources please? */
 		gdk_threads_enter();
-		ldapServer->idleId = gtk_idle_add(syldap_display_search_results, ldapServer);
+		ldapServer->idleId = gtk_idle_add((GtkFunction)syldap_display_search_results, ldapServer);
 		gdk_threads_leave();
 	}
 
@@ -1065,6 +1065,7 @@ gboolean syldap_test_connect( SyldapServer *ldapServer ) {
 * Test whether LDAP libraries installed.
 * Return: TRUE if library available.
 */
+#if 0
 gboolean syldap_test_ldap_lib() {
 	void *handle, *fun;
 	
@@ -1117,6 +1118,7 @@ gboolean syldap_test_ldap_lib() {
 
 	return TRUE;
 }
+#endif /* 0 */
 
 #endif	/* USE_LDAP */
 
