@@ -49,25 +49,31 @@ static Template *template_load(gchar *filename)
 
 	tmpl = g_new(Template, 1);
 	tmpl->name = NULL;
+	tmpl->subject = NULL;
+	tmpl->to = NULL;
+	tmpl->value = NULL;
 
 	while (fgets(buf, sizeof(buf), fp) != NULL) {
 		if (buf[0] == '\n')
 			break;
 		else if (!g_strncasecmp(buf, "Name:", 5))
 			tmpl->name = g_strdup(g_strstrip(buf + 5));
+		else if (!g_strncasecmp(buf, "Subject:", 8))
+			tmpl->subject = g_strdup(g_strstrip(buf + 8));
+		else if (!g_strncasecmp(buf, "To:", 3))
+			tmpl->to = g_strdup(g_strstrip(buf + 3));
 	}
 
 	if (!tmpl->name) {
 		g_warning("wrong template format\n");
-		g_free(tmpl);
+		template_free(tmpl);
 		return NULL;
 	}
 
 	if ((bytes_read = fread(buf, 1, sizeof(buf), fp)) == 0) {
 		if (ferror(fp)) {
 			FILE_OP_ERROR(filename, "fread");
-			g_free(tmpl->name);
-			g_free(tmpl);
+			template_free(tmpl);
 			return NULL;
 		}
 	}
@@ -80,6 +86,8 @@ static Template *template_load(gchar *filename)
 void template_free(Template *tmpl)
 {
 	g_free(tmpl->name);
+	g_free(tmpl->subject);
+	g_free(tmpl->to);
 	g_free(tmpl->value);
 	g_free(tmpl);
 }
@@ -156,7 +164,7 @@ void template_write_config(GSList *tmpl_list)
 
 	if (!is_dir_exist(path)) {
 		if (is_file_exist(path)) {
-			g_warning(_("file %s allready exists\n"), path);
+			g_warning(_("file %s already exists\n"), path);
 			return;
 		}
 		if (mkdir(path, S_IRWXU) < 0) {
@@ -186,6 +194,10 @@ void template_write_config(GSList *tmpl_list)
 		debug_print(_("%s:%d writing template \"%s\" to %s\n"),
 		            __FILE__, __LINE__, tmpl->name, filename);
 		fprintf(fp, "Name: %s\n", tmpl->name);
+		if (tmpl->subject && *tmpl->subject != '\0')
+			fprintf(fp, "Subject: %s\n", tmpl->subject);
+		if (tmpl->to && *tmpl->to != '\0')
+			fprintf(fp, "To: %s\n", tmpl->to);
 		fputs("\n", fp);
 		fwrite(tmpl->value, sizeof(gchar) * strlen(tmpl->value), 1,
 		       fp);
