@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2001 Hiroyuki Yamamoto
+ * Copyright (C) 1999-2002 Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -257,6 +257,10 @@ void unfold_line			(gchar		*str);
 void subst_char				(gchar		*str,
 					 gchar		 orig,
 					 gchar		 subst);
+void subst_chars			(gchar		*str,
+					 gchar		*orig,
+					 gchar		 subst);
+void subst_for_filename			(gchar		*str);
 gboolean is_header_line			(const gchar	*str);
 gboolean is_ascii_str			(const guchar	*str);
 gint get_quote_level			(const gchar	*str);
@@ -282,6 +286,7 @@ gchar *get_domain_name		(void);
 
 /* file / directory handling */
 off_t get_file_size		(const gchar	*file);
+off_t get_file_size_as_crlf	(const gchar	*file);
 off_t get_left_file_size	(FILE		*fp);
 gboolean file_exist		(const gchar	*file,
 				 gboolean	 allow_fifo);
@@ -301,6 +306,7 @@ gint move_file			(const gchar	*src,
 gint change_file_mode_rw	(FILE		*fp,
 				 const gchar	*file);
 FILE *my_tmpfile		(void);
+FILE *str_open_as_stream	(const gchar	*str);
 
 #define is_file_exist(file)		file_exist(file, FALSE)
 #define is_file_or_fifo_exist(file)	file_exist(file, TRUE)
